import { Pipe, PipeTransform } from '@angular/core';
import { GlobalState } from '@app/core/state';
import { State, select } from '@ngrx/store';

import { getAllVisibleTerms } from './../../degree-planner/selectors';
import { PlannedTerm } from './../../core/models/planned-term';

@Pipe({
  name: 'academicYearState',
})
export class AcademicYearStatePipe implements PipeTransform {
  terms: PlannedTerm[];
  constructor(private store: State<GlobalState>) {
    this.store
      .pipe(select(getAllVisibleTerms))
      .subscribe(terms => (this.terms = terms));
  }

  transform(year: string): string {
    const termCode = this.terms[0].termCode;
    let century = 2000;
    if (termCode.substr(0, 1) === '0') {
      century = 1900;
    }
    const YYYY = century + Number(year);

    if (year < termCode.substr(1, 2)) {
      return 'Past: ' + (YYYY - 1) + '-' + YYYY;
    } else if (year > termCode.substr(1, 2)) {
      return 'Future: ' + (YYYY - 1) + '-' + YYYY;
    } else {
      return 'Current: ' + (YYYY - 1) + '-' + YYYY;
    }
  }
}
